# QCV Harmonizer

A Python package that harmonize data following FAIREASE qcv nomenclature.

## Installation
WARNING : To use this package, it is needed to install cerberecontrib-marineinsitu package from git before. 
Hopefully, the command is written below .
Have fun !

To install cerberecontrib-marineinsitu, you can use `pip` directly from GitLab:

```bash
pip install git+https://gitlab.ifremer.fr/cerbere/cerberecontrib-marineinsitu.git@dev_cweber
```

Then it is posible to install qcvharmonizer package thru pip standard usage : 
```bash
pip install qcvharmonizer
``` 